#version 330 core

layout(location=0) in vec3 position;
layout(location=1) in vec2 vTexcoord;
layout(location=2) in vec3 normals;

out VertexData {
	vec2 fTexcoord;
	vec3 intensity;
} outData;

uniform mat4 model;
uniform mat4 norm;
uniform mat4 view;
uniform mat4 proj;
uniform vec3 pos;
uniform vec3 dir;
uniform vec3 intensity;

#define MAX_LIGHTS 4

void main(void) {
	gl_Position = proj * view * model * vec4(position, 1.0);

	vec4 _p = model * vec4(position, 1.0);
	vec3 p = vec3(_p.x/_p.w, _p.y/_p.w, _p.z/_p.w);

	vec4 _n = norm * vec4(normals, 1.0);
	vec3 n = vec3(_n.x/_n.w, _n.y/_n.w, _n.z/_n.w);
	n = normalize(n);

	vec3 totalIntensity = vec3(0,0,0);
	vec3 inten;
	float diffuse;

	for (int i=0;i<MAX_LIGHTS;i++){
		vec3 lightpos = pos + vec3(100 * i - 50, 35, 0);
		
		vec3 L = normalize(lightpos - p);

		float d = length(lightpos - p);
		float k = 1 / (0.1 + 0.01*d + 0.0*d*d);
		inten = intensity * vec3(k);

		diffuse = dot(n, L);
		if (diffuse < 0){
			diffuse = 0;
		}

		totalIntensity = totalIntensity + (inten * vec3(diffuse));
	}

	outData.intensity = totalIntensity;
	outData.fTexcoord = vTexcoord;
}