#version 330 core

layout(location=0) in vec3 position;
layout(location=1) in vec2 vTexcoord;
layout(location=2) in vec3 normals;

out	vec2 fTexcoord;
out vec3 fNormals;
out vec3 fPosition;
out vec4 shadowCoord1;
out vec4 shadowCoord2;
out vec4 shadowCoord3;

uniform mat4 model;
uniform mat4 view;
uniform mat4 proj;
uniform mat4 depthBias;
uniform mat4 depthVP1;
uniform mat4 depthVP2;
uniform mat4 depthVP3;

void main(void) {
	vec4 worldPosition = model * vec4(position, 1.0f);
	gl_Position = proj * view * worldPosition;

	shadowCoord1 = depthBias * depthVP1 * worldPosition;
	shadowCoord2 = depthBias * depthVP2 * worldPosition;
	shadowCoord3 = depthBias * depthVP3 * worldPosition;

	fNormals = mat3(transpose(inverse(model))) * normals;
	fTexcoord = vTexcoord;
	fPosition = worldPosition.xyz;

}